# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Mathml2latex do
  it 'has a version number' do
    expect(Mathml2latex::VERSION).not_to be nil
  end
end

RSpec.describe Mathml2latex::Converter do
  let(:service) { instance_double(Mathml2latex::MathmlLatexService) }

  before do
    expect(Mathml2latex::MathmlLatexService)
      .to receive(:get_service_object).and_return(service)
  end

  context '#to_latex' do
    subject { described_class.new.to_latex('some xml') }

    it 'directs calls to service' do
      expect(service).to receive(:to_latex)
      subject
    end
  end

  context '#replace_with_latex' do
    let(:xml_doc) { double }
    let(:node1) { double }
    let(:node2) { double }
    let(:nodes) do
      [node1, node2]
    end

    before do
      allow(xml_doc).to receive(:xpath).and_return(nodes)
      allow(node1).to receive(:dup).and_return(node1)
      allow(node2).to receive(:dup).and_return(node2)
    end

    subject { described_class.new.replace_with_latex(xml_doc) }

    it 'directs calls to service' do
      expect(service).to receive(:to_latex).twice
      expect(node1).to receive(:to_xml)
      expect(node2).to receive(:to_xml)
      expect(node1).to receive(:replace)
      expect(node2).to receive(:replace)
      subject
    end
  end
end
